
/***************************************************************************\
    "Freebox Remote Control", contrôle de la Freebox à distance
    Copyright (c) 2010 Blount
    This file is part of "Freebox Remote Control".

    "Freebox Remote Control" is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    "Freebox Remote Control" is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with "Freebox Remote Control".
    If not, see <http://www.gnu.org/licenses/>.
\***************************************************************************/

var ChannelsSort = new Class({
	
	Binds : ['sort'],
	Extends : Sortables,
	
	initialize : function(container)
	{
		this.parent(container, {onComplete: this.endSort});
		this._defaultOrder = this.serialize();
		
		this.update();
	},
	
	update : function()
	{
		var order = Config.options.orderChannels;
		if (order.length == 0) {
			order = this._defaultOrder;
		}
		var id, i;
		for (i = order.length - 1; i >= 0; i--) {
			id = $(order[i]);
			if (id && id.inject && id.getStyle('display') != 'none') {
				id.inject(this.lists[0], 'top');
			}
		}
	},
	
	endSort : function(element)
	{
		Config.setOptions({'orderChannels': this.serialize()}).save();
	},
	
	reInit : function() {
		Config.setOptions({'orderChannels': []}).save();
		this.update();
	}
	
});


/**
 * Si la chaîne est masquée, alors on la restaure dans la liste.
 * Sinon, on la masque.
 */
var toggleChannel = function(event) {
	event.stop();
	var id, el = this.getParent('li');
	id = el.get('id').replace(/[^0-9]*/g, '');
	
	el.setStyle('overflow', 'hidden');
	
	if (!Config.options.hiddenChannels.contains(id.toString())) {
		Config.options.hiddenChannels.push(id.toString());
	} else {
		Config.options.hiddenChannels.erase(id.toString());
	}
	
	Config.save();
	
	el.set('morph', {onComplete: function(el) {el.setStyle('display', 'none');}})
		.morph({'width': 0, 'opacity': 0});
};



/**
 * Liste des chaînes ayant un canal TNT
 */
var tntChannels = [];
tntChannels[1] = 701;
tntChannels[2] = 702;
tntChannels[3] = 703;
tntChannels[4] = 704;
tntChannels[5] = 705;
tntChannels[6] = 706;
tntChannels[7] = 706;
tntChannels[8] = 706;
tntChannels[9] = 709;
tntChannels[10] = 710;
tntChannels[11] = 711;
tntChannels[12] = 712;
tntChannels[13] = 713;
tntChannels[14] = 714;
tntChannels[15] = 715;
tntChannels[16] = 716;
tntChannels[17] = 717;
tntChannels[18] = 718;
/*
tntChannels[30] = 730;
tntChannels[31] = 731;
tntChannels[32] = 732;
tntChannels[33] = 733;
tntChannels[34] = 734;
tntChannels[35] = 735;
tntChannels[36] = 736;
tntChannels[37] = 737;
tntChannels[38] = 738;
tntChannels[39] = 739;
*/

var drawChannels = function() {
	if (!channels && !$('channels-list')) {
		return;
	}
	
	var key = document.location.href.toString().match(/[^/]*\.html/);
	if (key && key[0]) {
		key = key[0].replace(/\.html/, '');
	}
	key = key == 'chaines'?'delete':'add';
	
	/**
	 * Chargement de la liste des chaînes
	 */
	if (!channels) {
		channels = JSON.decode($('channels-list').get('value'));
	}
	
	var max, i = 0, lists = $(key == 'delete'?'channels':'channels-deleted').empty();
	var asset, j, channel, view, li, services;
	
	if (Config.options.channelsPerPage == 0 || key != 'delete') {
		max = channels.length;
		j = 0;
	} else {
		var nbPages = (channels.length / Config.options.channelsPerPage).toInt();
		max = Config.options.channelsPerPage;
		if (max > channels.length) {
			max = channels.length;
		}
		if (Config.options.currentPage > nbPages) {
			Config.options.currentPage = 1;
		}
		j = (Config.options.currentPage -1) * Config.options.channelsPerPage;
		max = j.toInt() + max.toInt();
	}
	
	
	for (j; j < max; j++) {
		channel =  channels[j];
		if (!channel) {
			continue;
		}
		
		//var view = channel.available;
		view = true;
		if (key == 'delete') {
			view = view && !Config.options.hiddenChannels.contains(channel.id.toString());
		} else {
			view = view && Config.options.hiddenChannels.contains(channel.id.toString());
		}
		
		if (view) {
			li = new Element('li', {id: 'c'+channel.id})
				.adopt(new Element('span', {text: channel.name}));
			
			services = new Element('div', {'class':'services'});
			li.adopt(services);
			
			if (tntChannels[channel.id]) {
				services.adopt(new Element('img', {
					src: 'images/tnt.png', alt: '',
					id: 'tnt-'+tntChannels[channel.id],
					'class': 'option'
				}));
			}
			
			lists.adopt(li);

			//console.log(channel.id);
			asset = Asset.image('images/logos/'+channel.id+'.png', {
				onload : function(img) {
					if (img.get('width') > 0) {
						var id = img.get('src').replace(/[^0-9]*/g, "");
						var li = $('c' + id);
						// les chaînes de France 3 doivent garder le texte
						if (id >= 300 && id <= 325) {
							var span = li.getElement('span');
							span.set('text', span.get('text').replace('France 3', ''));
							img.inject(span, 'before');
						} else {
							img.replaces(li.getElement('span'));
						}
					}
				}
			});
			
			if (channel.services) {
				channel.services.each(function(service) {
					if (service.desc == 'HD') {
						services.adopt(new Element('img', {
							src: 'images/hd.png', alt: '',
							id: 'hd-'+service.id,
							'class': 'option'
						}));
					}
				});
			}
			
			li.adopt(new Element('img', {
				src: 'images/'+key+'.png', alt: '',
				id: key+'-'+channel.id,
				'class': key
			}));
		}
	}
	
	
	if (max != channels.length) {
		if ($('pages')) {
			$('pages').destroy();
		}
		
		// pagination
		var ul = new Element('ul', {id:'pages', 'class':'pages'});
		var page, li;
		for (page = 1; page <= nbPages; page++) {
			li = new Element('li', {id: 'page-'+page});
			li.addEvent('click', function (event) {
				if ($('page-'+Config.options.currentPage)) {
					$('page-'+Config.options.currentPage).removeClass('selected');
				}
				Config.oldOptions.currentPage = Config.options.currentPage;
				Config.options.currentPage = this.get('id').replace(/[^0-9]*/g, "");
				this.addClass('selected');
				Config.save();
			});
			ul.adopt(li);
		}
		ul.inject($('channels'), 'after');
		(new Element('span', {'class':'clear'})).inject(ul, 'before');
		
		if ($('page-'+Config.options.currentPage)) {
			$('page-'+Config.options.currentPage).addClass('selected');
		}
	} else if ($('pages')) {
		$('pages').destroy();
	}
	
	$$('img.'+key).addEvent('click', toggleChannel);
	
	initChannels();
};






















