
/***************************************************************************\
    "Freebox Remote Control", contrôle de la Freebox à distance
    Copyright (c) 2010 Blount
    This file is part of "Freebox Remote Control".

    "Freebox Remote Control" is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    "Freebox Remote Control" is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with "Freebox Remote Control".
    If not, see <http://www.gnu.org/licenses/>.
\***************************************************************************/

/**
 * Paramêtre de l'API
 */
var CConfig = new Class({
	
	Implements : [Options, Events],
	
	options : {
		code : '',
		keyboard : false,
		decodeur : 'hd1',
		orderChannels : [],
		useUrlBackup: true,
		hiddenChannels : [],
		skin : 'freebox',
		channelsPerPage : 0,
		currentPage : 1
	},
	
	initialize : function (options) {
		this.setOptions(options);
		
		var datas;

		// localStorage implémenté ?
		this.supportLocalStorage = typeof localStorage !== 'undefined';
		if (this.supportLocalStorage) {
			datas = localStorage.getItem('config');
		}
		
		var href = document.location.href;
		if (href.test(/#config=/)) {
			datas = href.replace(/.*#config=/g, '');
		}
		
		if (datas) {
			this.setOptions(JSON.decode(Base64.decode(datas)));
		}
		this.oldOptions = this.options;
	},
	
	save : function () {
		var str = Base64.encode(JSON.encode(this.options));
		
		if (this.supportLocalStorage) {
			datas = localStorage.setItem('config', str);
		}

		if (this.options.useUrlBackup) {
			document.location.href = '#config=' + str;
		} else if (document.location.href.test(/#config=.*/)) {
			document.location.href = document.location.href.toString().replace(/#config=.*/, '');
		}
		
		this.fireEvent('save', [this, this.oldOptions]);
	},
	
	
	view : function () {
		if ($('settings')) {
			$('settings').destroy();
		}
		var container = new Element('div', {
			id: 'settings'
		});
		
		var form = new Element('form', {action: '', method: 'post'});
		form.set('html',
			'<fieldset>\
				<legend>Général</legend>\
				<ul>\
					<li id="choix-hdx">\
						<label for="hd1"><input type="radio" name="decodeur" id="hd1" value="hd1" checked="checked" /> HD1</label>\
						<label for="hd2"><input type="radio" name="decodeur" id="hd2" value="hd2" /> HD2</label>\
					</li>\
					<li>\
						<label for="code">Code box : <input type="text" name="code" id="code" value="" size="10" /></label>\
					</li>\
				</ul>\
			</fieldset>\
			<fieldset>\
				<legend>Mosaïque de chaînes</legend>\
				<ul>\
					<li><label for="channelsPerPage">\
						<input type="text" name="channelsPerPage" id="channelsPerPage" value="0" size="3" />\
						chaînes par page (0 = désactivé)\
						</label>\
					</li>\
				</ul>\
			</fieldset>\
			<fieldset>\
				<legend>Télécommande virtuelle</legend>\
				<ul>\
					<li><label for="keyboard"><input type="checkbox" id="keyboard" name="keyboard" value="1" /> Activer le clavier</label></li>\
					<li><label for="useUrlBackup"><input type="checkbox" id="useUrlBackup" name="useUrlBackup" value="1" /> Activer la sauvegarde par URL</label></li>\
					<li>\
						<label for="skin">Interface : \
							<select name="skin" id="skin">\
								<option value="freebox">Freebox HD</option>\
								<option value="alice">Alice HD</option>\
							</select>\
						</label>\
					</li>\
				</ul>\
				<p id="hidde-settings"><span id="cancel-settings">Annuler</span><span id="save-settings">Sauvegarder</span></p>\
			</fieldset>');
		container.adopt(form).inject($$('body')[0], 'top');

		$('keyboard').set('checked', this.options.keyboard == true);
		$('useUrlBackup').set('checked', this.options.useUrlBackup == true);
		$('code').set('value', this.options.code);
		$('skin').set('value', this.options.skin);
		$('channelsPerPage').set('value', this.options.channelsPerPage);
		$(this.options.decodeur).set('checked', true);
		
		$('cancel-settings').addEvent('click', function (event) {
			event.stop();
			form.destroy();
		});
		
		$('save-settings').addEvent('click', function (event) {
			event.stop();
			this.saveForm(event.target.getParent('form'));
			form.destroy();
		}.bind(this));
		
		// si on désactive la sauvegarde par URL, on alerte l'utilisateur si son navigateur ne supporte pas localStorage
		$('useUrlBackup').addEvent('click', function (event) {
			if (!this.get('checked') && !this.supportLocalStorage) {
				window.alert('Attention : votre navigateur ne supporte pas le localStorage.\nAucune sauvegarde ne sera effectuée.');
			}
		});
		
		form.addEvent('submit', function(event) {
			this.saveForm(event.target);
		}.bind(this));
		
		window.scrollTo(0, 0);
	},
	
	saveForm : function (form) {
		this.oldOptions = this.options;
		
		var queryString = {};
		form.getElements('input, select, textarea', true).each(function(el){
			if (!el.name || el.disabled || el.type == 'submit' || el.type == 'reset' || el.type == 'file') return;
			var value = (el.tagName.toLowerCase() == 'select') ? Element.getSelected(el).map(function(opt){
				return opt.value;
			}) : ((el.type == 'radio' || el.type == 'checkbox') && !el.checked) ? null : el.value;
			$splat(value).each(function(val){
				if (typeof val != 'undefined') queryString[el.name] = val;
			});
		});
		
		this.options.keyboard = false;
		this.options.useUrlBackup = false;
		this.setOptions(queryString).save();
	}
	
	
});











