
/***************************************************************************\
    "Freebox Remote Control", contrôle de la Freebox à distance
    Copyright (c) 2010 Blount
    This file is part of "Freebox Remote Control".

    "Freebox Remote Control" is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    "Freebox Remote Control" is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with "Freebox Remote Control".
    If not, see <http://www.gnu.org/licenses/>.
\***************************************************************************/


/**
 * Gestion de requête vers le boitier HD
 * @author Blount
 */
var Remote = new Class({
	
	Implements : [Events],
	
	
	initialize : function()
	{
		this._link = 'http://hd1.freebox.fr/pub/remote_control?';
		this._hdx = 'hd1';
		
		this.bounds = {
			keyboard : this.keyDown.bind(this)
		};
	},
	
	/**
	 * @param string channel
	 * @return void
	 */
	loadChannel : function(channel)
	{
		// chaîne numérique seulement
		if ('' == channel.replace(/[^0-9]*/g, '')) {
			return false;
		}
		
		var requests = [];
		var channelNumbers = channel.split(''); // découpe la chaîne en chiffre
		channelNumbers.each(function (number, i) {
			requests.push({key: number, long: (i+1) != channelNumbers.length});
		}.bind(this));
		
		this.request(requests);
	},
	
	/**
	 * Défini le code de la Freebox
	 * @param string code
	 * @return Remote
	 */
	setCode : function(code)
	{
		this._code = code;
		return this;
	},
	
	
	/**
	 * Exécute une requête sur la Freebox
	 * @param string key
	 * @param bool _long 
	 * @return Remote
	 */
	request : function(key, _long, repeat)
	{
		var date = new Date();
		
		if ($type(key) == 'array') {
			var requests = [];
			key.each(function (datas) {
				requests.push(this._link + (datas.long?'long=true&':'') +
					'code=' + this._code +
					'&key=' + datas.key +
					'&force=' + date.getTime() + Math.floor(Math.random()*5000));
			}.bind(this));
			var images = Asset.images(requests);
			return this;
		}
		
		var link = this._link;
		link += 'code=' + this._code;
		if (_long == true) {
			link += '&long=true';
		}
		if (repeat && repeat > 0) {
			link += '&repeat=' + repeat;
		}
		link += '&key=' + key;
		link += '&force=' + date.getTime() + Math.floor(Math.random() * 5000);
		
		var image = new Asset.image(link);
		
		return this;
	},
	
	
	/**
	 * Active ou non si le clavier
	 * @return Remote
	 */
	setKeyboard : function (statut)
	{
		if (statut) {
			window.addEvent('keydown', this.bounds.keyboard);
		} else {
			window.removeEvent('keydown', this.bounds.keyboard);
		}
		
		return this;
	},
	
	/**
	 * Filtre les appuis sur les touches du clavier
	 * @return void
	 */
	keyDown : function(event)
	{
		if (event.target.get('tag') != 'html') {
			return;
		}
		
		var key = event.key;
		//console.log(key);
		//console.log(event.code);
		
		var _long = false;
		var repeat = 0;
		
		// PV : pavé numérique
		switch(event.code) {
			case 8: key = 'back'; break;  //
			case 37: key = 'left'; break; //
			case 39: key = 'right'; break;// => flèches directionneles
			case 38: key = 'up'; break;   //
			case 40: key = 'down'; break; //
			
			case 13: key = 'ok'; break; // Enter
			case 109: key = 'vol_dec'; break; // -
			case 107:;
			case 61: key = 'vol_inc'; break; // + (PV) ou = 
			case 33: key = 'prgm_inc'; break; // page Up
			case 34: key = 'prgm_dec'; break; // Page Down
			case 36: key = 'home'; break; // Début
			case 188: key = 'mute'; break; // touche ",|?"
			
			case 65: key = 2; break;
			case 66: key = 2; repeat = 2; break;
			case 67: key = 2; repeat = 3; break;
			
			default: key = '';
		}
		
		if (key) {
			event.stop();
			this.request(key, _long, repeat);
		}
	},
	

	/**
	 * Défini le décodeur à cibler
	 * @param string hd
	 * @return Remote
	 */
	setHd : function(hd)
	{
		this._link = 'http://'+hd+'.freebox.fr/pub/remote_control?';
		var oldHd = this._hdx;
		this._hdx = hd;
		
		// génère un évènement
		this.fireEvent('changeHd', [oldHd, this._hdx]);
		
		return this;
	}
});
