
/***************************************************************************\
    "Freebox Remote Control", contrôle de la Freebox à distance
    Copyright (c) 2010 Blount
    This file is part of "Freebox Remote Control".

    "Freebox Remote Control" is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    "Freebox Remote Control" is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with "Freebox Remote Control".
    If not, see <http://www.gnu.org/licenses/>.
\***************************************************************************/

/**
 * Gère la télécommande virtuelle
 * @author Blount
 */
var RemoteControl = new Class({
	
	Implements : [Events],
	
	Binds : ['_push', '_click'],
	
	initialize : function(container, remote)
	{
		// touches acceptés
		this._keysList = ['red', 'green', 'blue', 'yellow', 'power',
			'tv', 'list', '0', '1', '2', '3', '4', '5', '6', '7', '8',
			'9', 'back', 'swap', 'info', 'mail', 'help', 'pip', 'ok',
			'mute', 'home', 'rec', 'play', 'stop', 'bwd', 'fwd', 'prev',
			'next', 'vol_inc', 'vol_dec', 'prgm_inc', 'prgm_dec', 'up',
			'right', 'down', 'left', 'guide', 'media', 'options', 'epg'
		];
		
		this._remote = remote;
		
		this._long = false;
		this._timerLong = false;
		this._timerVol = false;
		this._container = $(container);
	},
	
	
	/**
	 * Appui sur une touche : on lance un timer afin de savoir si ça va être
	 * un appui long
	 * @return void
	 */
	_push : function (event)
	{
		event.stop();
		var el = $(event.target);

		var key = el.get('href').replace(/.*\//, '');
		if (key == 'vol_inc' || key == 'vol_dec') {
			this._timerVol = this._remote.request.periodical(50, this._remote, [key, false]);
		}
		
		// on va contrôler si c'est un appuie long
		$clear(this._timerLong);
		this._timerLong = this._setLongTrue.delay(500, this);
	},
	
	
	/**
	 * Clique sur une touche de la télécommande
	 * @return void
	 */
	_click : function (event)
	{
		// on annule le timer s'il existe encore
		$clear(this._timerLong);
		event.stop();
		var el = $(event.target);
		var key = el.get('href').replace(/.*\//, '');
		
		if (key == 'vol_inc' || key == 'vol_dec') {
			$clear(this._timerVol);
			return;
		}
		
		
		// si le code de touche fait parti de la liste
		if (this._keysList.contains(key)) {
			// requête la Freebox
			this._remote.request(key, this._long);
		}
		
		// on réinitialise l'indication d'appui long
		this._long = false;
		
		// génération de l'évènement
		this.fireEvent('push', [el, key]);
	},
	
	
	/**
	 * Définis l'appui en cours comme long
	 * @return void
	 */
	_setLongTrue : function ()
	{
		this._long = true;
	},
	
	
	draw: function (type)
	{
		if (!remotes[type]) {
			return;
		}
		
		var image = new Element('img', {
			src: remotes[type].image, alt: '', usemap: '#remote'
		});
		image.setStyle('border', 'none');
		
		var map = new Element('map', {id: 'remote', name: 'remote'});
		this._container.empty().adopt(image, map);
		
		remotes[type].items.each(function (item) {
			if ($type(item) == 'element') {
				this._container.adopt(item);
			} else {
				var area = new Element('area', {
					shape: item.type,
					coords: item.coords,
					href: item.action,
					alt: ''
				});
				map.adopt(area);
			}
		}.bind(this));
		
		
		
		// groupe d'éléments utilisés pour simuler les touches de la télécommande
		map.getElements('area').addEvents({
			'mousedown' : this._push,
			'click' : this._click
		});
		
	}
	
});



var remotes = {
	'freebox' : {
		name: 'Freebox',
		image: 'images/telecommande-freebox.jpg',
		items: [
			{type: 'circle', coords: '87,48,16', action: 'red'},
			{type: 'circle', coords: '119,84,17', action: 'green'},
			{type: 'circle', coords: '86,115,16', action: 'blue'},
			{type: 'circle', coords: '53,82,17', action: 'yellow'},
			{type: 'circle', coords: '34,170,12', action: 'power'},
			{type: 'circle', coords: '139,170,11', action: 'tv'},
			{type: 'rect', coords: '69,166,104,181', action: 'list'},
			{type: 'rect', coords: '23,192,48,207', action: '1'},
			{type: 'rect', coords: '56,192,83,206', action: '2'},
			{type: 'rect', coords: '90,192,117,206', action: '3'},
			{type: 'rect', coords: '22,214,49,228', action: '4'},
			{type: 'rect', coords: '57,214,82,228', action: '5'},
			{type: 'rect', coords: '91,214,116,228', action: '6'},
			{type: 'rect', coords: '22,236,49,250', action: '7'},
			{type: 'rect', coords: '56,236,84,251', action: '8'},
			{type: 'rect', coords: '90,236,117,251', action: '9'},
			{type: 'rect', coords: '56,258,83,273', action: '0'},
			{type: 'rect', coords: '23,258,49,273', action: 'back'},
			{type: 'rect', coords: '91,258,116,273', action: 'swap'},
			{type: 'rect', coords: '124,192,150,207', action: 'info'},
			{type: 'rect', coords: '124,214,149,229', action: 'mail'},
			{type: 'rect', coords: '124,237,150,250', action: 'help'},
			{type: 'rect', coords: '124,258,150,272', action: 'pip'},
			{type: 'rect', coords: '74,318,98,342', action: 'ok'},
			{type: 'rect', coords: '22,378,47,395', action: 'mute'},
			{type: 'rect', coords: '63,377,109,405', action: 'home'},
			{type: 'rect', coords: '125,378,150,394', action: 'rec'},
			{type: 'rect', coords: '52,413,85,442', action: 'play'},
			{type: 'rect', coords: '92,413,116,441', action: 'stop'},
			{type: 'rect', coords: '21,405,47,423', action: 'bwd'},
			{type: 'rect', coords: '124,406,151,422', action: 'fwd'},
			{type: 'rect', coords: '21,434,48,450', action: 'prev'},
			{type: 'rect', coords: '125,432,150,449', action: 'next'},
			{type: 'rect', coords: '22,297,40,324', action: 'vol_inc'},
			{type: 'rect', coords: '21,335,40,362', action: 'vol_dec'},
			{type: 'rect', coords: '132,297,150,324', action: 'prgm_inc'},
			{type: 'rect', coords: '133,335,150,362', action: 'prgm_dec'},
			{type: 'poly', coords: '74,317,53,293,116,293,97,317', action: 'up'},
			{type: 'poly', coords: '100,317,117,294,123,301,122,362,118,366,100,342', action: 'right'},
			{type: 'poly', coords: '98,344,117,367,55,368,51,364,73,344', action: 'down'},
			{type: 'poly', coords: '49,363,49,298,52,295,73,318,73,343', action: 'left'},
			{type: 'rect', coords: '48,519,125,543', action: 'config'},
			new Element('input', {type: 'text', name: 'chaine', id: 'chaines-input', value: '000'})
		]
	},
	'alice' : {
		name: 'Alicebox',
		image: 'images/telecommande-alice.jpg',
		items: [
			{type: 'circle', coords: '87,88,21', action: 'play'},
			{type: 'circle', coords: '126,66,11', action: 'rec'},
			{type: 'circle', coords: '125,32,10', action: 'power'},
			{type: 'circle', coords: '120,118,10', action: 'next'},
			{type: 'circle', coords: '54,118,9', action: 'prev'},
			{type: 'circle', coords: '48,65,11', action: 'stop'},
			{type: 'rect', coords: '19,85,45,101', action: 'bwd'},
			{type: 'rect', coords: '127,84,154,101', action: 'fwd'},
			{type: 'circle', coords: '137,148,11', action: 'list'},
			{type: 'circle', coords: '86,179,16', action: 'ok'},
			{type: 'poly', coords: '106,166,118,155,126,166,129,181,128,193,120,203,119,205,106,194,111,179', action: 'right'},
			{type: 'poly', coords: '73,160,81,156,89,155,94,157,99,160,111,147,103,142,95,139,88,139,76,139,70,143,61,147', action: 'up'},
			{type: 'poly', coords: '54,155,68,166,64,174,63,179,64,185,66,191,67,194,54,206,50,196,46,183,46,173,48,165,52,158', action: 'left'},
			{type: 'poly', coords: '72,200,82,204,89,204,94,202,101,200,111,211,104,218,94,221,88,221,79,220,68,216,62,211', action: 'down'},
			{type: 'rect', coords: '70,237,104,260', action: 'mute'},
			{type: 'rect', coords: '27,305,47,323', action: 'red'},
			{type: 'rect', coords: '58,319,80,335', action: 'green'},
			{type: 'rect', coords: '93,318,115,336', action: 'yellow'},
			{type: 'rect', coords: '126,304,146,321', action: 'blue'},
			{type: 'circle', coords: '46,369,10', action: '1'},
			{type: 'circle', coords: '87,367,9', action: '2'},
			{type: 'circle', coords: '127,369,10', action: '3'},
			{type: 'circle', coords: '87,398,10', action: '5'},
			{type: 'circle', coords: '47,400,10', action: '4'},
			{type: 'circle', coords: '127,400,10', action: '6'},
			{type: 'circle', coords: '46,431,10', action: '7'},
			{type: 'circle', coords: '86,429,10', action: '8'},
			{type: 'circle', coords: '127,431,10', action: '9'},
			{type: 'circle', coords: '87,460,9', action: '0'},
			{type: 'circle', coords: '127,461,10', action: 'swap'},
			{type: 'circle', coords: '46,462,10', action: 'back'},
			{type: 'poly', coords: '85,286,99,286,105,286,108,288,112,293,111,302,106,309,96,311,81,311,71,309,64,306,61,299,61,294,62,290,68,287,77,286', action: 'home'},
			{type: 'circle', coords: '44,238,14', action: 'vol_inc'},
			{type: 'circle', coords: '50,272,13', action: 'vol_dec'},
			{type: 'circle', coords: '129,238,15', action: 'prgm_inc'},
			{type: 'circle', coords: '124,272,14', action: 'prgm_dec'},
			{type: 'circle', coords: '72,492,8', action: 'info'},
			{type: 'circle', coords: '45,487,9', action: 'help'},
			{type: 'circle', coords: '128,487,8', action: 'options'},
			{type: 'circle', coords: '102,492,9', action: 'guide'},
			{type: 'circle', coords: '87,48,8', action: 'media'},
			{type: 'circle', coords: '49,32,8', action: 'exit'},
			{type: 'rect', coords: '48,518,126,544', action: 'config'}
		]
	}
};













