/***************************************************************************\
    "Freebox Remote Control", contrôle de la Freebox à distance
    Copyright (c) 2010 Blount
    This file is part of "Freebox Remote Control".

    "Freebox Remote Control" is free software: you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    "Freebox Remote Control" is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with "Freebox Remote Control".
    If not, see <http://www.gnu.org/licenses/>.
\***************************************************************************/

var remote;
var Config;
var channels;

/**
 * Initialisation de l'API
 */
window.addEvent('domready', function() {
	
	
	Config = new CConfig();
	remote = new Remote();
	
	// Lorsque le numéro de décodeur change, on sélectionne le bon bouton sur la télécommande
	remote.addEvent('changeHd', function(oldHd, newHd) {
		Config.setOptions({decodeur: newHd}).save();
		if (!$(oldHd) || !$(newHd)) {
			return;
		}
		$(oldHd).removeClass('selected');
		$(newHd).addClass('selected');
	});
	
	remote.setHd(Config.options.decodeur);
	remote.setCode(Config.options.code);
	
	
	// initialisation de la télécommande
	initRemoteControl();
	
	
	drawChannels();
	
	
	// Lors de la sauvegarde des paramètres, on réinitalise les composants
	Config.addEvent('save', function (c, old) {
		remote.setCode(c.options.code);
		remote.setKeyboard(c.options.keyboard);
		if (c.options.channelsPerPage != old.channelsPerPage || c.options.currentPage != old.currentPage) {
			drawChannels();
		}
	});
	
	
	// ouverture du panneau de config
	if ($('config')) {
		$('config').addEvent('click', function (event) {
			event.stop();
			Config.view();
		});
	}
});


var initRemoteControl = function () {
	if (!$('remote')) {
		return;
	}
	
	//var control = new RemoteControl($('remote').getElements('area'), remote);
	var control = new RemoteControl('remote', remote);
	control.draw(Config.options.skin);
	Config.addEvent('save', function (c) {
		control.draw(c.options.skin);
	});
	
	// champ pour la sélection du chaîne
	if ($('chaines-input')) {
		$('chaines-input').store('timer-press', null)
			.store('event-keypress', function (event) {
				$clear(this.retrieve('timer-press'));
				this.store('timer-press', (function () {
					remote.loadChannel($('chaines-input').get('value'));
				}).delay(1000));
			});
		$('chaines-input').addEvent('click', function (event) {
			this.set('value', '');
			this.addEvent('keydown', this.retrieve('event-keypress'));
		});
	}
	
	control.addEvent('push', function (el, key) {
		if (key == 'config') {
			Config.view();
		}
	});
};


var initChannels = function () {

	// Système de tri des chaînes
	var channelsSort = new ChannelsSort('channels');
	if (remote && $('channels')) {
		var fnLoadChannel = function (event) {
			if (event.rightClick) {
				return;
			}
			var el = $(event.target);
			
			if (el.hasClass('delete') || el.hasClass('add')) {
				return;
			}
			
			if (!el.get('id')) {
				el = el.getParent('li');
			}
			var channel = el.get('id').replace(/[^0-9]*/g, '');
			remote.loadChannel(channel);
		};
		
		// Chargement d'une chaîne au clique sur l'icône
		$('channels').getElements('li').addEvent('mouseup', fnLoadChannel);
		
		channelsSort.addEvents({
			'start': function () {
				// désactive le click quand on déplace : empêche le charge de la chaîne
				$('channels').getElements('li').removeEvent('mouseup', fnLoadChannel);
			},
			'onComplete' : function () {
				// on remet les détections de click
				$('channels').getElements('li').addEvent('mouseup', fnLoadChannel);
			}
		});
		
		// remise à zéro de l'ordre des chaînes
		if ($('reset-order-channels')) {
			$('reset-order-channels').addEvent('click', function (event) {
				event.stop();
				channelsSort.reInit();
			});
		}
	}
};





